@@ -679,7 +679,10 @@ class buildable(ebd, setup_mixin, format.build):
         # fetch distfiles
         if not self.verified_files:
             ops = self.domain.pkg_operations(self.pkg, observer=self.observer)
-            ops.fetch()
+            if ops.fetch():
+                # this break encapsulation and should be refactored.  Trace
+                # f35f2 and 6561eac for where this was refactored.
+                self.verified_files = ops.verified_files
 
         # symlink them into builddir
         if self.verified_files:
