@@ -1,16 +1,15 @@
 import argparse
+import operator
 from collections import defaultdict
 from itertools import chain
-import operator
 
 from snakeoil.cli import arghparse
 from snakeoil.osutils import pjoin
 from snakeoil.sequences import split_negations
 
-from pkgcore.ebuild import atom, profiles
-from pkgcore.ebuild.misc import ChunkedDataDict
-from pkgcore.util import commandline
-
+from ..util import commandline
+from . import atom, profiles
+from .misc import ChunkedDataDict
 
 commands = []
 # info: keywords known
