@@ -144,7 +144,7 @@ class PortageConfig(DictMixin):
             make_conf, pjoin(self.dir, 'make.conf'), required=False,
             allow_sourcing=True, incrementals=True)
 
-        self.root = os.environ.get("ROOT", kwargs.pop('root', make_conf.get("ROOT", "/")))
+        self.root = kwargs.pop('root', make_conf.get("ROOT", "/"))
         gentoo_mirrors = [
             x.rstrip("/") + "/distfiles" for x in make_conf.pop("GENTOO_MIRRORS", "").split()]
 
@@ -224,16 +224,10 @@ class PortageConfig(DictMixin):
         if forced_buildpkg:
             make_conf['FEATURES'] += ' buildpkg'
 
-        # now add the fetcher- we delay it till here to clean out the environ
-        # it passes to the command.
-        # *everything* in make_conf must be str values also.
-        self._add_fetcher(make_conf)
-
         # finally... domain.
         make_conf.update({
             'class': 'pkgcore.ebuild.domain.domain',
             'repos': tuple(repos),
-            'fetcher': 'fetcher',
             'default': True,
             'vdb': ('vdb',),
             'profile': 'profile',
@@ -437,7 +431,7 @@ class PortageConfig(DictMixin):
                 d['class'] = 'pkgcore.sync.base.AutodetectSyncer'
             else:
                 # disable syncing if sync-uri is explicitly unset
-                d['class'] = 'pkgcore.sync.base.DisabledSyncer'
+                d['class'] = 'pkgcore.sync.base.DisabledSync'
 
             name = 'sync:' + repo_name
             self[name] = basics.AutoConfigSection(d)
@@ -511,19 +505,6 @@ class PortageConfig(DictMixin):
                 "profile": paths[1],
             })
 
-    def _add_fetcher(self, make_conf):
-        fetchcommand = make_conf.pop("FETCHCOMMAND")
-        resumecommand = make_conf.pop("RESUMECOMMAND", fetchcommand)
-
-        fetcher_dict = {
-            "class": "pkgcore.fetch.custom.fetcher",
-            "distdir": os.path.normpath(make_conf.pop("DISTDIR")),
-            "command": fetchcommand,
-            "resume_command": resumecommand,
-            "attempts": make_conf.pop("FETCH_ATTEMPTS", '10'),
-        }
-        self["fetcher"] = basics.AutoConfigSection(fetcher_dict)
-
     def _isolate_rsync_opts(self, options):
         """
         pop the misc RSYNC related options littered in make.conf, returning
